"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MULTICALL3_ABI = exports.MULTICALL3_ADDRESS = void 0;
exports.multicall3Bundler = multicall3Bundler;
const viem_1 = require("viem");
// Multicall3 contract address (deployed on most chains)
exports.MULTICALL3_ADDRESS = "0xcA11bde05977b3631167028862bE2a173976CA11";
// Multicall3 ABI for the aggregate3 and aggregate3Value functions
exports.MULTICALL3_ABI = [
    {
        inputs: [
            {
                components: [
                    { name: "target", type: "address" },
                    { name: "allowFailure", type: "bool" },
                    { name: "value", type: "uint256" },
                    { name: "callData", type: "bytes" },
                ],
                name: "calls",
                type: "tuple[]",
            },
        ],
        name: "aggregate3Value",
        outputs: [
            {
                components: [
                    { name: "success", type: "bool" },
                    { name: "returnData", type: "bytes" },
                ],
                name: "returnData",
                type: "tuple[]",
            },
        ],
        stateMutability: "payable",
        type: "function",
    },
];
/**
 * Bundle multiple calls using Multicall3. This bundler will change the msg.sender of the calls to the
 * Multicall3 contract and this might affect the result of the calls.
 */
function multicall3Bundler(pythUpdate, call) {
    // Encode the multicall3 aggregate3 function call
    const multicallData = (0, viem_1.encodeFunctionData)({
        abi: exports.MULTICALL3_ABI,
        functionName: "aggregate3Value",
        args: [
            [
                {
                    target: pythUpdate.call.to,
                    allowFailure: false,
                    value: pythUpdate.call.value ?? 0n,
                    callData: pythUpdate.call.data ?? "0x",
                },
                {
                    target: call.to,
                    allowFailure: false,
                    value: call.value ?? 0n,
                    callData: call.data ?? "0x",
                },
            ],
        ],
    });
    // Calculate total value needed
    const totalValue = (call.value ?? 0n) + (pythUpdate.call.value ?? 0n);
    // Create the bundled transaction that calls multicall3
    return {
        to: exports.MULTICALL3_ADDRESS,
        data: multicallData,
        value: totalValue,
        from: call.from,
    };
}
