import { Address, BlockTag, CallParameters, Client, ExactPartial, Hex, RpcTransactionRequest } from "viem";
/**
 * Extract Pyth price feed IDs from a transaction call trace.
 */
export declare function extractPythPriceFeedsFromDebugTraceCall(trace: RpcCallTrace, pythContractAddress: Address, ignoreParsingErrors?: boolean): Set<`0x${string}`>;
export type TraceCallRpcSchema = {
    Method: "debug_traceCall";
    Parameters: [ExactPartial<RpcTransactionRequest>, Hex | BlockTag] | [
        ExactPartial<RpcTransactionRequest>,
        BlockTag | Hex,
        {
            tracer: "callTracer" | "prestateTracer";
            tracerConfig?: {
                onlyTopCall?: boolean;
                withLog?: boolean;
            };
        }
    ];
    ReturnType: RpcCallTrace;
};
export type RpcCallType = "CALL" | "STATICCALL" | "DELEGATECALL" | "CREATE" | "CREATE2" | "SELFDESTRUCT" | "CALLCODE";
export type RpcLogTrace = {
    address: Address;
    data: Hex;
    position: Hex;
    topics: [Hex, ...Hex[]];
};
export type RpcCallTrace = {
    from: Address;
    gas: Hex;
    gasUsed: Hex;
    to: Address;
    input: Hex;
    output: Hex;
    error?: string;
    revertReason?: string;
    calls?: RpcCallTrace[];
    logs?: RpcLogTrace[];
    value?: Hex;
    type: RpcCallType;
};
export declare const debugTraceCallAction: (client: Client) => {
    debugTraceCall(args: CallParameters): Promise<RpcCallTrace>;
};
//# sourceMappingURL=debug-trace-call.d.ts.map