"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.debugTraceCallAction = void 0;
exports.extractPythPriceFeedsFromDebugTraceCall = extractPythPriceFeedsFromDebugTraceCall;
const viem_1 = require("viem");
const pyth_abi_1 = require("../pyth-abi");
/**
 * Extract Pyth price feed IDs from a transaction call trace.
 */
function extractPythPriceFeedsFromDebugTraceCall(trace, pythContractAddress, ignoreParsingErrors = false) {
    const result = new Set();
    if (trace.to === pythContractAddress) {
        // Decode the calldata to see what function is being called
        try {
            const decoded = (0, viem_1.decodeFunctionData)({
                abi: pyth_abi_1.IPythAbi,
                data: trace.input,
            });
            let priceFeedId;
            switch (decoded.functionName) {
                case "getPrice":
                case "getPriceNoOlderThan":
                case "getPriceUnsafe":
                case "getEmaPrice":
                case "getEmaPriceNoOlderThan":
                case "getEmaPriceUnsafe": {
                    priceFeedId = decoded.args[0];
                    break;
                }
                default: {
                    break;
                }
            }
            if (priceFeedId !== undefined) {
                result.add(priceFeedId);
            }
        }
        catch {
            if (!ignoreParsingErrors) {
                throw new Error(`Failed to decode calldata: ${trace.input}. Make sure correct Pyth contract address is used.`);
            }
        }
    }
    if (trace.calls === undefined) {
        return new Set();
    }
    return new Set([
        ...result,
        ...trace.calls.flatMap((call) => [
            ...extractPythPriceFeedsFromDebugTraceCall(call, pythContractAddress),
        ]),
    ]);
}
const debugTraceCallAction = (client) => ({
    async debugTraceCall(args) {
        return client.request({
            method: "debug_traceCall",
            params: [
                (0, viem_1.formatTransactionRequest)(args),
                "latest",
                { tracer: "callTracer" },
            ],
        });
    },
});
exports.debugTraceCallAction = debugTraceCallAction;
