import { Address, BlockTag, RpcTransactionRequest, ExactPartial, Hex, Client, CallParameters } from "viem";
/**
 * Extract Pyth price feed IDs from a transaction call trace.
 */
export declare function extractPythPriceFeedsFromTraceCallMany(traceResults: TraceCallResult[], pythContractAddress: Address, ignoreParsingErrors?: boolean): Set<`0x${string}`>;
export type TraceCallResult = {
    output: Hex;
    stateDiff: undefined;
    trace: RpcCallTrace[];
    vmTrace: undefined;
};
export type TraceCallRpcSchema = {
    Method: "trace_callMany";
    Parameters: [
        [
            ExactPartial<RpcTransactionRequest>,
            ["trace"]
        ][],
        Hex | BlockTag
    ];
    ReturnType: TraceCallResult[];
};
export type RpcCallTrace = {
    action: {
        from: Address;
        callType: "call" | "staticcall" | "delegatecall" | "create" | "create2" | "selfdestruct" | "callcode";
        gas: Hex;
        input: Hex;
        to: Address;
        value: Hex;
    };
    result: {
        gasUsed: Hex;
        output: Hex;
    };
    subtraces: number;
    traceAddress: number[];
    type: "call" | "create";
};
export declare const traceCallManyAction: (client: Client) => {
    traceCallMany(args: CallParameters[]): Promise<TraceCallResult[]>;
};
//# sourceMappingURL=trace-call-many.d.ts.map