"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.traceCallManyAction = void 0;
exports.extractPythPriceFeedsFromTraceCallMany = extractPythPriceFeedsFromTraceCallMany;
const viem_1 = require("viem");
const pyth_abi_1 = require("../pyth-abi");
/**
 * Extract Pyth price feed IDs from a transaction call trace.
 */
function extractPythPriceFeedsFromTraceCallMany(traceResults, pythContractAddress, ignoreParsingErrors = false) {
    const result = new Set();
    for (const traceResult of traceResults) {
        for (const trace of traceResult.trace) {
            if (trace.action.to === pythContractAddress) {
                // Decode the calldata to see what function is being called
                try {
                    const decoded = (0, viem_1.decodeFunctionData)({
                        abi: pyth_abi_1.IPythAbi,
                        data: trace.action.input,
                    });
                    let priceFeedId;
                    switch (decoded.functionName) {
                        case "getPrice":
                        case "getPriceNoOlderThan":
                        case "getPriceUnsafe":
                        case "getEmaPrice":
                        case "getEmaPriceNoOlderThan":
                        case "getEmaPriceUnsafe": {
                            priceFeedId = decoded.args[0];
                            break;
                        }
                        default: {
                            break;
                        }
                    }
                    if (priceFeedId !== undefined) {
                        result.add(priceFeedId);
                    }
                }
                catch {
                    if (!ignoreParsingErrors) {
                        throw new Error(`Failed to decode calldata: ${trace.action.input}. Make sure correct Pyth contract address is used.`);
                    }
                }
            }
        }
    }
    return result;
}
const traceCallManyAction = (client) => ({
    async traceCallMany(args) {
        return client.request({
            method: "trace_callMany",
            params: [
                args.map((a) => [(0, viem_1.formatTransactionRequest)(a), ["trace"]]),
                "latest",
            ],
        });
    },
});
exports.traceCallManyAction = traceCallManyAction;
